@@ -7,6 +7,7 @@ Smart commands that understand item-level progress and prevent fraud.
 
 from typing import Tuple, Optional
 from ..client import get_client
+from ..context_analyzer import analyze_card_movement
 
 
 def cmd_check(card_id: str, checklist_name: str, item_name: str, validate_fraud: bool = True):
@@ -82,9 +83,28 @@ def cmd_check(card_id: str, checklist_name: str, item_name: str, validate_fraud:
         print(f"✅ Checked: {item_name}")
         print(f"   Progress: {new_completed}/{total} items ({completion_rate:.0f}%)")
 
+        # Add Claude AI comment about progress
+        progress_message = f"✅ Item completed: {item_name}\n"
+        progress_message += f"📊 Progress: {new_completed}/{total} ({completion_rate:.0f}% done)"
+
         if new_completed == total:
+            progress_message += f"\n\n🎉 All items complete! Ready for final review."
             print(f"\n🎉 Checklist complete! Card is ready for Done.")
 
+        try:
+            card.comment(progress_message)
+        except Exception as e:
+            print(f"⚠️  Could not add comment: {e}")
+
+        # If checklist is complete, add Claude analysis
+        if new_completed == total:
+            try:
+                analysis = analyze_card_movement(card, checklist_name_val, "Completed")
+                print(analysis)
+            except Exception as e:
+                # Silently fail if Claude analysis is not available
+                pass
+
         return True
 
     except Exception as e:
@@ -143,6 +163,15 @@ def cmd_uncheck(card_id: str, checklist_name: str, item_name: str):
         print(f"↩️  Unchecked: {item_name}")
         print(f"   Progress: {new_completed}/{total} items ({completion_rate:.0f}%)")
 
+        # Add comment about unchecking
+        unchecked_message = f"↩️ Item marked incomplete: {item_name}\n"
+        unchecked_message += f"📊 Progress: {new_completed}/{total} ({completion_rate:.0f}% done)"
+
+        try:
+            card.comment(unchecked_message)
+        except Exception as e:
+            print(f"⚠️  Could not add comment: {e}")
+
         return True
 
     except Exception as e:
